Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(102)

Unified Diff: sync/internal_api/public/test/test_user_share.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sync/internal_api/public/test/test_entry_factory.h ('k') | sync/internal_api/public/user_share.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sync/internal_api/public/test/test_user_share.h
diff --git a/sync/internal_api/public/test/test_user_share.h b/sync/internal_api/public/test/test_user_share.h
index 3c11d49f9961eb0ed7e16032b1fc1f2dab8d697f..0fb15031ae343b62334bdcf5f9afde463548a5ed 100644
--- a/sync/internal_api/public/test/test_user_share.h
+++ b/sync/internal_api/public/test/test_user_share.h
@@ -3,7 +3,7 @@
// found in the LICENSE file.
//
// A handy class that takes care of setting up and destroying a
// csync::UserShare instance for unit tests that require one.
//
// The expected usage is to make this a component of your test fixture:
//
@@ -22,7 +22,7 @@
// Then, in your tests:
//
// TEST_F(AwesomenessTest, IsMaximal) {
-// csync::ReadTransaction trans(test_user_share_.user_share());
+// syncer::ReadTransaction trans(test_user_share_.user_share());
// ...
// }
//
@@ -34,7 +34,7 @@
#include "base/basictypes.h"
#include "sync/internal_api/public/user_share.h"
-namespace csync {
+namespace syncer {
class TestDirectorySetterUpper;
@@ -54,15 +54,15 @@ class TestUserShare {
void TearDown();
// Non-NULL iff called between a call to SetUp() and TearDown().
- csync::UserShare* user_share();
+ syncer::UserShare* user_share();
private:
scoped_ptr<TestDirectorySetterUpper> dir_maker_;
- scoped_ptr<csync::UserShare> user_share_;
+ scoped_ptr<syncer::UserShare> user_share_;
DISALLOW_COPY_AND_ASSIGN(TestUserShare);
};
-} // namespace csync
+} // namespace syncer
#endif // SYNC_INTERNAL_API_PUBLIC_TEST_TEST_USER_SHARE_H_
« no previous file with comments | « sync/internal_api/public/test/test_entry_factory.h ('k') | sync/internal_api/public/user_share.h » ('j') | no next file with comments »
@@ -3,7 +3,7 @@
//
// A handy class that takes care of setting up and destroying a
-// csync::UserShare instance for unit tests that require one.
+// syncer::UserShare instance for unit tests that require one.
//
// The expected usage is to make this a component of your test fixture:

Powered by Google App Engine
This is Rietveld 408576698